#include "StdAfx.h"
#include ".\uvset.h"


IMPLEMENT_SERIAL( UvSet, CObject, 1 )



UvSet::~UvSet(void)
{
	for ( int i=0; i < returnSize( ); i++ )
	{
		delete at(i);
	}
}

void UvSet::addCondition(char *name)
{
	conditions.Add( new Uv( name ) );
}


void UvSet::WriteAllConditionsToOutFile(OutFile *outFile, int lineNumber)
{
	for ( int i = 0; i < returnSize( ); i++)
	{
		at(i)->WriteConditionToOutFile( outFile, lineNumber, i ); 
	}
}

void UvSet::SetAllValues( WTextFile *theTextFile )
{
	CString buffer;
	
	for (int i=0; i < returnSize( ); i++)
	{	
		buffer = theTextFile->at( at(i)->m_row, at(i)->m_column )->c_str( );
		at(i)->setValue( buffer );
	}
}

InputErrorUv UvSet::checkValidInputs( WTextFile * theTextFile )
{
	InputErrorUv inputErrorUv;
	int row, column;
	
	for (int i=0; i < returnSize( ); i++)
	{
		row = at( i )->m_row;
		column = at( i )->m_column;
		
		if( (row < 0) || (row > (theTextFile->returnNumberOfLines() - 1)) )
		{
			inputErrorUv.errorCode = 1;
			inputErrorUv.errorString = _T( "Invalid row number" );
			inputErrorUv.errorRow = row;
			inputErrorUv.uvWithError = i;
			return inputErrorUv;
		}

		if( (column < 0) || (column > (theTextFile->returnNumberOfColumns() - 1)) )
		{
			inputErrorUv.errorCode = 2;
			inputErrorUv.errorString = _T( "Invalid column number" );
			inputErrorUv.errorColumn = column;
			inputErrorUv.uvWithError = i;
			return inputErrorUv;
		}
	}

	return inputErrorUv;
}

void UvSet::clear(void)
{
	conditions.RemoveAll( );
}

Uv *UvSet::at( int index )
{
	return conditions.GetAt( index );
}

int UvSet::returnSize( )
{
	return conditions.GetCount( );
}

void UvSet::Serialize( CArchive& archive )
{
	CObject::Serialize( archive );

	if( archive.IsStoring( ) ) // save
	{
		archive << returnSize( );


		for( int i=0; i < returnSize( ); i++ )
		{
			at( i )->Serialize( archive );
		}
	}
	else // load
	{
		int size;
		archive >> size;

		conditions.SetSize( size );

		for( int i=0; i < size; i++ )
		{
			conditions[i] = new Uv;
			at( i )->Serialize( archive );
		}
	}
}


